@@ -6,62 +6,42 @@ use warnings;
 use Carp;
 use Scalar::Util qw/ reftype /;
 
-use overload '&{}'  => \&_overload_func,
-             q{""}  => \&_overload_quote;
+{
 
-our $VERSION = '1.50.1';
-
-our @ALLOWED_ATTRIBUTES = qw{
-  pre post
-  intro extro
-  prechildren postchildren
-  prechild testcode
-  showtag
-  postchild
-  action
-  rename
-  content contents
-};
+our @ALLOWED_ATTRIBUTES =  qw/ pre post testcode showtag
+                               intro extro prechildren postchildren
+                               prechild postchild action /;
 
 sub new {
-   return bless {}, shift;
+   my( $class ) = @_;
+
+   my $self = {};
+   bless $self, $class;
+
+   return $self;
 }
 
 sub get {
-    my $self = shift;
-    return wantarray ? map { $self->{$_} } @_
-                     : $self->{$_[0]}
-                     ;
+    my( $self, @attributes ) = @_;
+
+    return map { $self->{$_} || '' } @attributes;
 }
 
 sub set {
 	my( $self, $attribute_ref ) = @_;
 
 	for my $key ( keys %{$attribute_ref} ) {
-        croak "attribute $key not allowed"
+        croak "attribute $key not allowed" 
             if ! grep { $key eq $_ } @ALLOWED_ATTRIBUTES;
 
         $self->{$key} = $attribute_ref->{$key};
-
-        # renaming implies showing the tag
-        $self->{showtag} = 1 if $key eq 'rename';
 	}
 
 	return;
 }
 
-sub _overload_func {
-    my $self = shift;
-    return sub { $self->set( @_ ) }
-}
-
-sub _overload_quote {
-    my $self = shift;
-    return $self;
-    return sub { print $self };
-}
-
 'end of XML::XPathScript::Template::Tag';
+}
 
 __END__
 
@@ -71,7 +51,7 @@ __END__
 
 =head1 NAME
 
-XML::XPathScript::Template::Tag - XPathScript Template Element 
+XML::XPathScript::Template::Tag - Tag within a XML::XPathScript::Template 
 
 =head1 SYNOPSIS
 
@@ -94,7 +74,7 @@ XML::XPathScript::Template::Tag - XPathScript Template Element
 The XML::XPathScript::Tag class is used to represent tags 
 within an XPathScript template. 
 
-=head1 CALLED AS ARGUMENT TO THE TESTCODE FUNCTIONS
+=head2 Called as Argument to the testcode Functions
 
 Typically, the only time you'll be exposed to those objects is
 via the testcode functions, which receive as arguments a reference
@@ -115,14 +95,10 @@ Example:
             if( $n->findvalue( './@bar' ) eq 'whonk' ) {
                 # we've been whonk'ed! This foo must
                 # blink
-                $t->set({ 
-                    'pre' => '<blink>', 'post' => '</blink>' 
-                });
+                $t->set({ 'pre' => '<blink>', 'post' => '</blink>' });
 
                 # and the next foos will be in italic
-                $template->set( foo => { 
-                    pre => '<i>', post => '</i>' 
-                } );
+                $template->set( foo => { pre => '<i>', post => '</i>' } );
             }
             return DO_SELF_AND_CHILDREN();
         }
@@ -130,30 +106,27 @@ Example:
 
 =head1 METHODS
 
-=head2 new
+=over
 
-    $tag = XML::XPathScript::Template::Tag->new
+=item new
 
-Creates a new, empty tag.
+    $tag = new XML::XPathScript::Template::Tag;
 
-=head2 set
+Create a new, empty tag.
 
-    $t->set( \%attributes )
+=item set
+
+    $t->set( \%attributes );
 
 Updates the tag's attributes with the values given in \%attributes
 
-Thanks to the magic of overloading, using I<$t> as a function 
-reference acts as a shortcut to I<set>.
-
 Example:
 
     $t->set({ pre => '<a>', post => '</a>' });
-    # or, equivalently,
-    $t->({ pre => '<a>', post => '</a>' });
 
-=head2 get
+=item get
 
-    @values = $tag->get( @attributes )
+    my @values = $tag->get( @attributes );
 
 Returns the values of @attributes.
 
@@ -161,6 +134,8 @@ Example:
 
     @values = $tag->get( 'pre', 'post' );
 
+=back
+
 =head1 BACKWARD COMPATIBILITY
 
 As for XML::XPathScript::Template, prior to release 1.0 of XPathScript, 
@@ -171,7 +146,6 @@ to the tag attributes were done by manipulating the hash directly.
     <%
         $t->{foo}{testcode} = sub {  
             my( $n, $t ) = @_;
-
             $t->{pre} = '<a>';
             $t->{post} = '</a>';
 
@@ -186,23 +160,21 @@ is deprecated. Instead, it is recommended to use the object's
 access methods.
 
     <%
-        $template->set( foo => { testcode => \&tc_foo } );
-        sub tc_foo {  
+        $t->{foo}{testcode} = sub {  
             my( $n, $t ) = @_;
-           
-            $t->set({ 
-                pre => '<a>', post => '</a>' 
-            });
-            
+            $t->set({ pre => '<a>', post => '</a>' });
+
             return DO_SELF_AND_CHILDREN;
         };
     %>
 
-=head1 BUGS 
+=head1 BUGS AND LIMITATIONS
 
-Please send bug reports to <bug-xml-xpathscript@rt.cpan.org>,
-or via the web interface at 
-http://rt.cpan.org/Public/Dist/Display.html?Name=XML-XPathScript .
+There are no known bugs in this module.
+
+Please report problems to Yanick Champoux <yanick@cpan.org>
+
+Patches are welcome.
 
 =head1 AUTHOR
 
